@@ -11,6 +11,7 @@ from zope.schema.interfaces import IContextSourceBinder
 from zope.schema import vocabulary
 from zope.viewlet.interfaces import IViewlet
 from zope.formlib import form
+from zope.app.component.hooks import getSite
 
 from zExceptions import Unauthorized
 from zc.table import table, column
@@ -86,7 +87,11 @@ class OrderListingComponent( core.EventViewlet ):
     
     columns = [
         column.GetterColumn( title=_(u"Order Id"), getter=renderOrderId ),
-        column.GetterColumn( title=_(u"Customer Id"), getter=AttrColumn("user_id" ) ),        
+        column.GetterColumn( title=_(u"Customer Id"), getter=AttrColumn("user_id" ) ), 
+        column.GetterColumn( title=_(u"Last4"), getter=AttrColumn("user_payment_info_last4" ) ),
+        column.GetterColumn( title=_(u"Proc Trans Id"), getter=AttrColumn("user_payment_info_trans_id" ) ),       
+        column.GetterColumn( title=_(u"Name on Card"), getter=AttrColumn("name_on_card" ) ),       
+        column.GetterColumn( title=_(u"Card Phone#"), getter=AttrColumn("bill_phone_number" ) ),       
         column.GetterColumn( title=_(u"Status"), getter=AttrColumn("finance_state") ),
         column.GetterColumn( title=_(u"Fulfillment"), getter=AttrColumn("fulfillment_state") ),
         column.GetterColumn( title=_(u"Price"), getter=PriceColumn("getTotalPrice") ),
@@ -99,6 +104,10 @@ class OrderListingComponent( core.EventViewlet ):
         return self.template()
     
     def listing( self ):
+        for column in self.columns:
+            if hasattr(column, 'title'):
+                column.title = getSite().translate(msgid=column.title, domain='plonegetpaid')
+
         columns = self.columns
         values = self.manager.get('orders-search').results
         if not values:
@@ -545,9 +554,18 @@ class OrderSummaryComponent( viewlet.ViewletBase ):
     def fulfillment_status( self ):
         return self.order.fulfillment_state
 
+    def user_payment_info_trans_id(self):
+	    return self.order.user_payment_info_trans_id
+
+    def user_payment_info_last4(self):
+        return self.order.user_payment_info_last4
+	
     def finance_status( self ):
-        return self.order.finance_state
-        
+        return self.order.finance_state   
+    
+    def mockmethod(self):
+        return 'test-value'
+
     def getContactInformation(self):
         contact = self.order.contact_information
         contact ={'name': contact.name,
@@ -769,6 +787,10 @@ class OrderContentsComponent( core.ComponentViewlet ):
         return selected        
         
     def listing( self ):
+        for column in self.columns:
+            if hasattr(column, 'title'):
+                column.title = getSite().translate(msgid=column.title, domain='plonegetpaid')
+
         columns = self.columns
         formatter = table.StandaloneFullFormatter( self.context,
                                                    self.request,
