@@ -2,7 +2,7 @@
 
 cart-review checkout
 
-$Id: checkout.py 2249 2009-02-02 15:41:16Z lucielejard $
+$Id: checkout.py 2460 2009-05-04 07:56:15Z ilja.everila@twinapex.com $
 """
 
 
@@ -16,6 +16,7 @@ from zope.formlib import form
 from zope import schema, interface
 from zope.app.event.objectevent import ObjectCreatedEvent
 from zope.app.renderer.plaintext import PlainTextToHTMLRenderer
+from zope.app.component.hooks import getSite
 
 from zope import component
 
@@ -177,6 +178,7 @@ class BaseCheckoutForm( BaseFormView ):
         # shopping cart is attached to the session, but we want to switch the storage to the persistent
         # zodb, we pickle to get a clean copy to store.
         adapters = self.wizard.data_manager.adapters
+
         order.shopping_cart = loads( dumps( shopping_cart ) )
 
         for section in ('contact_information','billing_address','shipping_address'):
@@ -190,7 +192,6 @@ class BaseCheckoutForm( BaseFormView ):
         return order
 
     def canDisplayWidget (self, widget):
-#        import pdb;pdb.set_trace()
         portal = getToolByName(self.context, 'portal_url').getPortalObject()
         try:
             IGetPaidManagementOptions(portal).use_contact_me_with_offers
@@ -564,6 +565,10 @@ class CheckoutReviewAndPay( BaseCheckoutForm ):
         if not cart:
             return _(u"N/A")
 
+        for column in self.columns:
+            if hasattr(column, 'title'):
+                column.title = getSite().translate(msgid=column.title, domain='plonegetpaid')
+
         # create an order so that tax/shipping utilities have full order information
         # to determine costs (ie. billing/shipping address ).
         order = self.createTransientOrder()
